package cz.muni.fi.pa165.core.rest;

import cz.muni.fi.pa165.core.api.AirplaneApi;
import cz.muni.fi.pa165.core.api.AirplaneApiDelegate;
import cz.muni.fi.pa165.core.model.AirplaneDto;
import cz.muni.fi.pa165.core.model.NewAirplaneDtoRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
public class AirplaneController implements AirplaneApiDelegate {

    /**
     * POST /api/airplanes/{airplaneId}/airplaneTypes/{airplaneTypeId} : Assign airplane type to a airplane.
     *
     * @param airplaneId     (required)
     * @param airplaneTypeId (required)
     * @return OK (status code 201)
     * or Input data not correct (status code 400)
     * @see AirplaneApi#assignAirplaneType
     */
    @Override
    public ResponseEntity<AirplaneDto> assignAirplaneType(Long airplaneId, Long airplaneTypeId) {
        return AirplaneApiDelegate.super.assignAirplaneType(airplaneId, airplaneTypeId);
    }

    /**
     * POST /api/airplanes : Create a new airplane.
     * Creates a new airplane and returns it as a response.
     *
     * @param newAirplaneDtoRequest (required)
     * @return Created (status code 201)
     * or Input data not correct (status code 400)
     * @see AirplaneApi#createAirplane
     */
    @Override
    public ResponseEntity<AirplaneDto> createAirplane(NewAirplaneDtoRequest newAirplaneDtoRequest) {
        return AirplaneApiDelegate.super.createAirplane(newAirplaneDtoRequest);
    }

    /**
     * DELETE /api/airplanes/{id} : Delete airplane by id.
     *
     * @param id (required)
     * @return Deleted (status code 204)
     * or Not Found (status code 404)
     * @see AirplaneApi#deleteAirplane
     */
    @Override
    public ResponseEntity<Void> deleteAirplane(Long id) {
        return AirplaneApiDelegate.super.deleteAirplane(id);
    }

    /**
     * DELETE /api/airplanes/{airplaneId}/airplaneTypes/{airplaneTypeId} : Delete assignment of airplane type to an airplane.
     *
     * @param airplaneId     (required)
     * @param airplaneTypeId (required)
     * @return Deleted (status code 204)
     * or Not Found (status code 404)
     * @see AirplaneApi#deleteAirplaneTypeAssignment
     */
    @Override
    public ResponseEntity<Void> deleteAirplaneTypeAssignment(Long airplaneId, Long airplaneTypeId) {
        return AirplaneApiDelegate.super.deleteAirplaneTypeAssignment(airplaneId, airplaneTypeId);
    }

    /**
     * GET /api/airplanes/{id} : Get airplane by id.
     * Returns an object representing an airplane.
     *
     * @param id (required)
     * @return OK (status code 200)
     * @see AirplaneApi#getAirplaneById
     */
    @Override
    public ResponseEntity<AirplaneDto> getAirplaneById(Long id) {
        return AirplaneApiDelegate.super.getAirplaneById(id);
    }

    /**
     * GET /api/airplanes : Get all airplanes.
     * Returns an array of objects representing airplanes.
     *
     * @return OK (status code 200)
     * @see AirplaneApi#getAllAirplanes
     */
    @Override
    public ResponseEntity<List<AirplaneDto>> getAllAirplanes() {
        return AirplaneApiDelegate.super.getAllAirplanes();
    }

    /**
     * PUT /api/airplanes/{id} : Update airplane by id.
     * Updates a airplane by id and returns it as a response.
     *
     * @param id          (required)
     * @param airplaneDto (required)
     * @return OK (status code 200)
     * or Input data not correct (status code 400)
     * @see AirplaneApi#updateAirplane
     */
    @Override
    public ResponseEntity<AirplaneDto> updateAirplane(Long id, AirplaneDto airplaneDto) {
        return AirplaneApiDelegate.super.updateAirplane(id, airplaneDto);
    }

    /**
     * PUT /api/airplanes/{airplaneId}/airplaneTypes/{airplaneTypeId} : Update assignment of airplane type to an airplane.
     *
     * @param airplaneId     (required)
     * @param airplaneTypeId (required)
     * @return OK (status code 200)
     * or Input data not correct (status code 400)
     * @see AirplaneApi#updateAirplaneTypeAssignment
     */
    @Override
    public ResponseEntity<AirplaneDto> updateAirplaneTypeAssignment(Long airplaneId, Long airplaneTypeId) {
        return AirplaneApiDelegate.super.updateAirplaneTypeAssignment(airplaneId, airplaneTypeId);
    }
}
