package cz.muni.fi.pa165.core.rest;

import cz.muni.fi.pa165.core.api.AirportApi;
import cz.muni.fi.pa165.core.api.AirportApiDelegate;
import cz.muni.fi.pa165.core.model.AirportDto;
import cz.muni.fi.pa165.core.model.NewAirportDtoRequest;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@RestController
public class AirportController implements AirportApiDelegate {

    /**
     * POST /api/airports/{airportId}/arrivingFlights/{arrivingFlightId} : Assign arriving flight to an airport.
     *
     * @param airportId        (required)
     * @param arrivingFlightId (required)
     * @return OK (status code 201)
     * or Input data not correct (status code 400)
     * @see AirportApi#assignArrivingFlight
     */
    @Override
    public ResponseEntity<AirportDto> assignArrivingFlight(Long airportId, Long arrivingFlightId) {
        return AirportApiDelegate.super.assignArrivingFlight(airportId, arrivingFlightId);
    }

    /**
     * POST /api/airports/{airportId}/departingFlights/{departingFlightId} : Assign departing flight to an airport.
     *
     * @param airportId         (required)
     * @param departingFlightId (required)
     * @return OK (status code 201)
     * or Input data not correct (status code 400)
     * @see AirportApi#assignDepartingFlight
     */
    @Override
    public ResponseEntity<AirportDto> assignDepartingFlight(Long airportId, Long departingFlightId) {
        return AirportApiDelegate.super.assignDepartingFlight(airportId, departingFlightId);
    }

    /**
     * POST /api/airports : Create a new airport.
     * Creates a new airport and returns it as a response.
     *
     * @param newAirportDtoRequest (required)
     * @return Created (status code 201)
     * or Input data not correct (status code 400)
     * @see AirportApi#createAirport
     */
    @Override
    public ResponseEntity<AirportDto> createAirport(NewAirportDtoRequest newAirportDtoRequest) {
        return AirportApiDelegate.super.createAirport(newAirportDtoRequest);
    }

    /**
     * DELETE /api/airports/{id} : Delete airport by id.
     *
     * @param id (required)
     * @return Deleted (status code 204)
     * or Not Found (status code 404)
     * @see AirportApi#deleteAirport
     */
    @Override
    public ResponseEntity<Void> deleteAirport(Long id) {
        return AirportApiDelegate.super.deleteAirport(id);
    }

    /**
     * DELETE /api/airports/{airportId}/arrivingFlights/{arrivingFlightId} : Delete assignment of arriving flight to an airport.
     *
     * @param airportId        (required)
     * @param arrivingFlightId (required)
     * @return Deleted (status code 204)
     * or Not Found (status code 404)
     * @see AirportApi#deleteArrivingFlightAssignment
     */
    @Override
    public ResponseEntity<Void> deleteArrivingFlightAssignment(Long airportId, Long arrivingFlightId) {
        return AirportApiDelegate.super.deleteArrivingFlightAssignment(airportId, arrivingFlightId);
    }

    /**
     * DELETE /api/airports/{airportId}/departingFlights/{departingFlightId} : Delete assignment of departing flight to an airport.
     *
     * @param airportId         (required)
     * @param departingFlightId (required)
     * @return Deleted (status code 204)
     * or Not Found (status code 404)
     * @see AirportApi#deleteDepartingFlightAssignment
     */
    @Override
    public ResponseEntity<Void> deleteDepartingFlightAssignment(Long airportId, Long departingFlightId) {
        return AirportApiDelegate.super.deleteDepartingFlightAssignment(airportId, departingFlightId);
    }

    /**
     * GET /api/airports/{id} : Get airport by id.
     * Returns an object representing an airport.
     *
     * @param id (required)
     * @return OK (status code 200)
     * @see AirportApi#getAirportById
     */
    @Override
    public ResponseEntity<AirportDto> getAirportById(Long id) {
        return AirportApiDelegate.super.getAirportById(id);
    }

    /**
     * GET /api/airports : Get all airports.
     * Returns an array of objects representing airports.
     *
     * @return OK (status code 200)
     * @see AirportApi#getAllAirports
     */
    @Override
    public ResponseEntity<List<AirportDto>> getAllAirports() {
        return AirportApiDelegate.super.getAllAirports();
    }

    /**
     * PUT /api/airports/{id} : Update city by id.
     * Updates a airport by id and returns it as a response.
     *
     * @param id         (required)
     * @param airportDto (required)
     * @return OK (status code 200)
     * or Input data not correct (status code 400)
     * @see AirportApi#updateAirport
     */
    @Override
    public ResponseEntity<AirportDto> updateAirport(Long id, AirportDto airportDto) {
        return AirportApiDelegate.super.updateAirport(id, airportDto);
    }

    /**
     * PUT /api/airports/{airportId}/arrivingFlights/{arrivingFlightId} : Update assignment of arriving flight to an airport.
     *
     * @param airportId        (required)
     * @param arrivingFlightId (required)
     * @return OK (status code 200)
     * or Input data not correct (status code 400)
     * @see AirportApi#updateArrivingFlightAssignment
     */
    @Override
    public ResponseEntity<AirportDto> updateArrivingFlightAssignment(Long airportId, Long arrivingFlightId) {
        return AirportApiDelegate.super.updateArrivingFlightAssignment(airportId, arrivingFlightId);
    }

    /**
     * PUT /api/airports/{airportId}/departingFlights/{departingFlightId} : Update assignment of departing flight to an airport.
     *
     * @param airportId         (required)
     * @param departingFlightId (required)
     * @return OK (status code 200)
     * or Input data not correct (status code 400)
     * @see AirportApi#updateDepartingFlightAssignment
     */
    @Override
    public ResponseEntity<AirportDto> updateDepartingFlightAssignment(Long airportId, Long departingFlightId) {
        return AirportApiDelegate.super.updateDepartingFlightAssignment(airportId, departingFlightId);
    }
}
