package cz.muni.fi.pa165.core;

import com.fasterxml.jackson.databind.ObjectMapper;
import cz.muni.fi.pa165.core.model.CountryDto;
import cz.muni.fi.pa165.core.model.NewCountryDtoRequest;
import org.junit.jupiter.api.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.AutoConfigureMockMvc;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.http.MediaType;
import org.springframework.test.web.servlet.MockMvc;

import static org.assertj.core.api.Assertions.assertThat;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.post;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.jsonPath;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

/**
 * Integration tests. Run by "maven verify".
 */
@SpringBootTest
@AutoConfigureMockMvc
class CoreApplicationIT {

    private static final Logger log = LoggerFactory.getLogger(CoreApplicationIT.class);

    @Autowired
    private MockMvc mockMvc;

    @Autowired
    ObjectMapper objectMapper;

    @Test
    void createCountryTest() throws Exception {
        log.debug("createCountryTest() running");

        var expectedId = 42L;
        var expectedName = "Uganda";
        var newCountryDtoRequest = new NewCountryDtoRequest();
        newCountryDtoRequest.setName("Canadaa");

        var response = mockMvc.perform(
                post("/api/countries")
                        .contentType(MediaType.APPLICATION_JSON)
                        .content(objectMapper.writeValueAsString(newCountryDtoRequest))
                )
                .andExpect(status().isCreated())
                .andExpect(jsonPath("$.id").value(expectedId))
                .andExpect(jsonPath("$.name").value(expectedName))
                .andReturn().getResponse().getContentAsString();
        log.debug("response: {}", response);

        var countryDtoResponse = objectMapper.readValue(response, CountryDto.class);
        assertThat(countryDtoResponse.getId()).isEqualTo(expectedId);
        assertThat(countryDtoResponse.getName()).isEqualTo(expectedName);
    }

    @Test
    void getCountryByIdTest() throws Exception {
        log.debug("getCountryByIdTest() running");

        var expectedId = 4242L;
        var expectedName = "Fraaaance";

        var response = mockMvc.perform(get("/api/countries/42"))
                .andExpect(status().isOk())
                .andExpect(jsonPath("$.id").value(expectedId))
                .andExpect(jsonPath("$.name").value(expectedName))
                .andReturn().getResponse().getContentAsString();
        log.debug("response: {}", response);

        var countryDtoResponse = objectMapper.readValue(response, CountryDto.class);
        assertThat(countryDtoResponse.getId()).isEqualTo(expectedId);
        assertThat(countryDtoResponse.getName()).isEqualTo(expectedName);
    }
}
